"""RollerBearing"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.implicit import overridable, enum_with_selected_value
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal import (
    constructor,
    enum_with_selected_value_runtime,
    conversion,
    utility,
)
from mastapy._private.bearings import _1943
from mastapy._private.bearings.bearing_designs.rolling import _2218
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ROLLER_BEARING = python_net_import(
    "SMT.MastaAPI.Bearings.BearingDesigns.Rolling", "RollerBearing"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, List, TypeVar

    from mastapy._private.bearings.roller_bearing_profiles import _1980, _1991
    from mastapy._private.bearings.bearing_designs.rolling import (
        _2190,
        _2191,
        _2192,
        _2195,
        _2201,
        _2202,
        _2213,
        _2214,
        _2222,
        _2223,
        _2224,
        _2227,
    )
    from mastapy._private.bearings.bearing_designs import _2184, _2187, _2183

    Self = TypeVar("Self", bound="RollerBearing")
    CastSelf = TypeVar("CastSelf", bound="RollerBearing._Cast_RollerBearing")


__docformat__ = "restructuredtext en"
__all__ = ("RollerBearing",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RollerBearing:
    """Special nested class for casting RollerBearing to subclasses."""

    __parent__: "RollerBearing"

    @property
    def rolling_bearing(self: "CastSelf") -> "_2218.RollingBearing":
        return self.__parent__._cast(_2218.RollingBearing)

    @property
    def detailed_bearing(self: "CastSelf") -> "_2184.DetailedBearing":
        from mastapy._private.bearings.bearing_designs import _2184

        return self.__parent__._cast(_2184.DetailedBearing)

    @property
    def non_linear_bearing(self: "CastSelf") -> "_2187.NonLinearBearing":
        from mastapy._private.bearings.bearing_designs import _2187

        return self.__parent__._cast(_2187.NonLinearBearing)

    @property
    def bearing_design(self: "CastSelf") -> "_2183.BearingDesign":
        from mastapy._private.bearings.bearing_designs import _2183

        return self.__parent__._cast(_2183.BearingDesign)

    @property
    def asymmetric_spherical_roller_bearing(
        self: "CastSelf",
    ) -> "_2190.AsymmetricSphericalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2190

        return self.__parent__._cast(_2190.AsymmetricSphericalRollerBearing)

    @property
    def axial_thrust_cylindrical_roller_bearing(
        self: "CastSelf",
    ) -> "_2191.AxialThrustCylindricalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2191

        return self.__parent__._cast(_2191.AxialThrustCylindricalRollerBearing)

    @property
    def axial_thrust_needle_roller_bearing(
        self: "CastSelf",
    ) -> "_2192.AxialThrustNeedleRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2192

        return self.__parent__._cast(_2192.AxialThrustNeedleRollerBearing)

    @property
    def barrel_roller_bearing(self: "CastSelf") -> "_2195.BarrelRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2195

        return self.__parent__._cast(_2195.BarrelRollerBearing)

    @property
    def crossed_roller_bearing(self: "CastSelf") -> "_2201.CrossedRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2201

        return self.__parent__._cast(_2201.CrossedRollerBearing)

    @property
    def cylindrical_roller_bearing(
        self: "CastSelf",
    ) -> "_2202.CylindricalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2202

        return self.__parent__._cast(_2202.CylindricalRollerBearing)

    @property
    def needle_roller_bearing(self: "CastSelf") -> "_2213.NeedleRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2213

        return self.__parent__._cast(_2213.NeedleRollerBearing)

    @property
    def non_barrel_roller_bearing(self: "CastSelf") -> "_2214.NonBarrelRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2214

        return self.__parent__._cast(_2214.NonBarrelRollerBearing)

    @property
    def spherical_roller_bearing(self: "CastSelf") -> "_2222.SphericalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2222

        return self.__parent__._cast(_2222.SphericalRollerBearing)

    @property
    def spherical_roller_thrust_bearing(
        self: "CastSelf",
    ) -> "_2223.SphericalRollerThrustBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2223

        return self.__parent__._cast(_2223.SphericalRollerThrustBearing)

    @property
    def taper_roller_bearing(self: "CastSelf") -> "_2224.TaperRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2224

        return self.__parent__._cast(_2224.TaperRollerBearing)

    @property
    def toroidal_roller_bearing(self: "CastSelf") -> "_2227.ToroidalRollerBearing":
        from mastapy._private.bearings.bearing_designs.rolling import _2227

        return self.__parent__._cast(_2227.ToroidalRollerBearing)

    @property
    def roller_bearing(self: "CastSelf") -> "RollerBearing":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class RollerBearing(_2218.RollingBearing):
    """RollerBearing

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROLLER_BEARING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def corner_radii(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.CornerRadii

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @corner_radii.setter
    @enforce_parameter_types
    def corner_radii(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.CornerRadii = value

    @property
    def effective_roller_length(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EffectiveRollerLength

        if temp is None:
            return 0.0

        return temp

    @property
    def element_diameter(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.ElementDiameter

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @element_diameter.setter
    @enforce_parameter_types
    def element_diameter(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.ElementDiameter = value

    @property
    def kl(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.KL

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @kl.setter
    @enforce_parameter_types
    def kl(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.KL = value

    @property
    def roller_length(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.RollerLength

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @roller_length.setter
    @enforce_parameter_types
    def roller_length(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.RollerLength = value

    @property
    def roller_profile(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes":
        """EnumWithSelectedValue[mastapy._private.bearings.RollerBearingProfileTypes]"""
        temp = self.wrapped.RollerProfile

        if temp is None:
            return None

        value = (
            enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.wrapped_type()
        )
        return enum_with_selected_value_runtime.create(temp, value)

    @roller_profile.setter
    @enforce_parameter_types
    def roller_profile(self: "Self", value: "_1943.RollerBearingProfileTypes") -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = (
            enum_with_selected_value.EnumWithSelectedValue_RollerBearingProfileTypes.implicit_type()
        )
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        self.wrapped.RollerProfile = value

    @property
    def inner_race_profile_set(self: "Self") -> "_1980.ProfileSet":
        """mastapy._private.bearings.roller_bearing_profiles.ProfileSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerRaceProfileSet

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def outer_race_profile_set(self: "Self") -> "_1980.ProfileSet":
        """mastapy._private.bearings.roller_bearing_profiles.ProfileSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterRaceProfileSet

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def roller_profile_set(self: "Self") -> "_1980.ProfileSet":
        """mastapy._private.bearings.roller_bearing_profiles.ProfileSet

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RollerProfileSet

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def inner_race_and_roller_profiles(
        self: "Self",
    ) -> "List[_1991.RollerRaceProfilePoint]":
        """List[mastapy._private.bearings.roller_bearing_profiles.RollerRaceProfilePoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerRaceAndRollerProfiles

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def inner_race_and_roller_profiles_for_first_row(
        self: "Self",
    ) -> "List[_1991.RollerRaceProfilePoint]":
        """List[mastapy._private.bearings.roller_bearing_profiles.RollerRaceProfilePoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerRaceAndRollerProfilesForFirstRow

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def inner_race_and_roller_profiles_for_second_row(
        self: "Self",
    ) -> "List[_1991.RollerRaceProfilePoint]":
        """List[mastapy._private.bearings.roller_bearing_profiles.RollerRaceProfilePoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerRaceAndRollerProfilesForSecondRow

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def outer_race_and_roller_profiles(
        self: "Self",
    ) -> "List[_1991.RollerRaceProfilePoint]":
        """List[mastapy._private.bearings.roller_bearing_profiles.RollerRaceProfilePoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterRaceAndRollerProfiles

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def outer_race_and_roller_profiles_for_first_row(
        self: "Self",
    ) -> "List[_1991.RollerRaceProfilePoint]":
        """List[mastapy._private.bearings.roller_bearing_profiles.RollerRaceProfilePoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterRaceAndRollerProfilesForFirstRow

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def outer_race_and_roller_profiles_for_second_row(
        self: "Self",
    ) -> "List[_1991.RollerRaceProfilePoint]":
        """List[mastapy._private.bearings.roller_bearing_profiles.RollerRaceProfilePoint]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterRaceAndRollerProfilesForSecondRow

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_RollerBearing":
        """Cast to another type.

        Returns:
            _Cast_RollerBearing
        """
        return _Cast_RollerBearing(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.gears.gear_designs.klingelnberg_hypoid._1001 import (
        KlingelnbergCycloPalloidHypoidGearDesign,
    )
    from mastapy._private.gears.gear_designs.klingelnberg_hypoid._1002 import (
        KlingelnbergCycloPalloidHypoidGearMeshDesign,
    )
    from mastapy._private.gears.gear_designs.klingelnberg_hypoid._1003 import (
        KlingelnbergCycloPalloidHypoidGearSetDesign,
    )
    from mastapy._private.gears.gear_designs.klingelnberg_hypoid._1004 import (
        KlingelnbergCycloPalloidHypoidMeshedGearDesign,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.gear_designs.klingelnberg_hypoid._1001": [
            "KlingelnbergCycloPalloidHypoidGearDesign"
        ],
        "_private.gears.gear_designs.klingelnberg_hypoid._1002": [
            "KlingelnbergCycloPalloidHypoidGearMeshDesign"
        ],
        "_private.gears.gear_designs.klingelnberg_hypoid._1003": [
            "KlingelnbergCycloPalloidHypoidGearSetDesign"
        ],
        "_private.gears.gear_designs.klingelnberg_hypoid._1004": [
            "KlingelnbergCycloPalloidHypoidMeshedGearDesign"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "KlingelnbergCycloPalloidHypoidGearDesign",
    "KlingelnbergCycloPalloidHypoidGearMeshDesign",
    "KlingelnbergCycloPalloidHypoidGearSetDesign",
    "KlingelnbergCycloPalloidHypoidMeshedGearDesign",
)



"""TransientSolver"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.nodal_analysis.system_solvers import _106
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_TRANSIENT_SOLVER = python_net_import(
    "SMT.MastaAPI.NodalAnalysis.SystemSolvers", "TransientSolver"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.nodal_analysis import _92
    from mastapy._private.nodal_analysis.system_solvers import (
        _103,
        _105,
        _107,
        _108,
        _109,
        _112,
        _117,
        _120,
        _118,
        _116,
    )

    Self = TypeVar("Self", bound="TransientSolver")
    CastSelf = TypeVar("CastSelf", bound="TransientSolver._Cast_TransientSolver")


__docformat__ = "restructuredtext en"
__all__ = ("TransientSolver",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_TransientSolver:
    """Special nested class for casting TransientSolver to subclasses."""

    __parent__: "TransientSolver"

    @property
    def dynamic_solver(self: "CastSelf") -> "_106.DynamicSolver":
        return self.__parent__._cast(_106.DynamicSolver)

    @property
    def stiffness_solver(self: "CastSelf") -> "_118.StiffnessSolver":
        from mastapy._private.nodal_analysis.system_solvers import _118

        return self.__parent__._cast(_118.StiffnessSolver)

    @property
    def solver(self: "CastSelf") -> "_116.Solver":
        from mastapy._private.nodal_analysis.system_solvers import _116

        return self.__parent__._cast(_116.Solver)

    @property
    def backward_euler_transient_solver(
        self: "CastSelf",
    ) -> "_103.BackwardEulerTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _103

        return self.__parent__._cast(_103.BackwardEulerTransientSolver)

    @property
    def dirk_transient_solver(self: "CastSelf") -> "_105.DirkTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _105

        return self.__parent__._cast(_105.DirkTransientSolver)

    @property
    def internal_transient_solver(self: "CastSelf") -> "_107.InternalTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _107

        return self.__parent__._cast(_107.InternalTransientSolver)

    @property
    def lobatto_iiic_transient_solver(
        self: "CastSelf",
    ) -> "_108.LobattoIIICTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _108

        return self.__parent__._cast(_108.LobattoIIICTransientSolver)

    @property
    def newmark_transient_solver(self: "CastSelf") -> "_109.NewmarkTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _109

        return self.__parent__._cast(_109.NewmarkTransientSolver)

    @property
    def simple_velocity_based_step_halving_transient_solver(
        self: "CastSelf",
    ) -> "_112.SimpleVelocityBasedStepHalvingTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _112

        return self.__parent__._cast(_112.SimpleVelocityBasedStepHalvingTransientSolver)

    @property
    def step_halving_transient_solver(
        self: "CastSelf",
    ) -> "_117.StepHalvingTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _117

        return self.__parent__._cast(_117.StepHalvingTransientSolver)

    @property
    def wilson_theta_transient_solver(
        self: "CastSelf",
    ) -> "_120.WilsonThetaTransientSolver":
        from mastapy._private.nodal_analysis.system_solvers import _120

        return self.__parent__._cast(_120.WilsonThetaTransientSolver)

    @property
    def transient_solver(self: "CastSelf") -> "TransientSolver":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class TransientSolver(_106.DynamicSolver):
    """TransientSolver

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TRANSIENT_SOLVER

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def average_number_of_jacobian_evaluations_per_newton_raphson_solve(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AverageNumberOfJacobianEvaluationsPerNewtonRaphsonSolve

        if temp is None:
            return 0.0

        return temp

    @property
    def interface_analysis_time(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InterfaceAnalysisTime

        if temp is None:
            return 0.0

        return temp

    @property
    def number_of_attempted_single_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfAttemptedSingleSteps

        if temp is None:
            return 0

        return temp

    @property
    def number_of_failed_newton_raphson_solves(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfFailedNewtonRaphsonSolves

        if temp is None:
            return 0

        return temp

    @property
    def number_of_failed_time_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfFailedTimeSteps

        if temp is None:
            return 0

        return temp

    @property
    def number_of_failed_time_steps_at_minimum_time_step(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfFailedTimeStepsAtMinimumTimeStep

        if temp is None:
            return 0

        return temp

    @property
    def number_of_interface_time_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfInterfaceTimeSteps

        if temp is None:
            return 0

        return temp

    @property
    def number_of_newton_raphson_jacobian_evaluations(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNewtonRaphsonJacobianEvaluations

        if temp is None:
            return 0

        return temp

    @property
    def number_of_newton_raphson_maximum_iterations_reached(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNewtonRaphsonMaximumIterationsReached

        if temp is None:
            return 0

        return temp

    @property
    def number_of_newton_raphson_other_status_results(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNewtonRaphsonOtherStatusResults

        if temp is None:
            return 0

        return temp

    @property
    def number_of_newton_raphson_residual_evaluations(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNewtonRaphsonResidualEvaluations

        if temp is None:
            return 0

        return temp

    @property
    def number_of_newton_raphson_residual_tolerance_met(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNewtonRaphsonResidualToleranceMet

        if temp is None:
            return 0

        return temp

    @property
    def number_of_newton_raphson_solves(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNewtonRaphsonSolves

        if temp is None:
            return 0

        return temp

    @property
    def number_of_newton_raphson_values_not_changing(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfNewtonRaphsonValuesNotChanging

        if temp is None:
            return 0

        return temp

    @property
    def number_of_successful_single_steps(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfSuccessfulSingleSteps

        if temp is None:
            return 0

        return temp

    @property
    def number_of_time_steps_taken(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfTimeStepsTaken

        if temp is None:
            return 0

        return temp

    @property
    def number_of_times_single_step_function_failed(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfTimesSingleStepFunctionFailed

        if temp is None:
            return 0

        return temp

    @property
    def number_of_times_step_error_tolerance_not_met(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfTimesStepErrorToleranceNotMet

        if temp is None:
            return 0

        return temp

    @property
    def solver_status(self: "Self") -> "_92.TransientSolverStatus":
        """mastapy._private.nodal_analysis.TransientSolverStatus"""
        temp = self.wrapped.SolverStatus

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.NodalAnalysis.TransientSolverStatus"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.nodal_analysis._92", "TransientSolverStatus"
        )(value)

    @solver_status.setter
    @enforce_parameter_types
    def solver_status(self: "Self", value: "_92.TransientSolverStatus") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.NodalAnalysis.TransientSolverStatus"
        )
        self.wrapped.SolverStatus = value

    def times_of_logged_results(self: "Self") -> "List[float]":
        """List[float]"""
        return conversion.pn_to_mp_objects_in_list(
            self.wrapped.TimesOfLoggedResults(), float
        )

    @property
    def cast_to(self: "Self") -> "_Cast_TransientSolver":
        """Cast to another type.

        Returns:
            _Cast_TransientSolver
        """
        return _Cast_TransientSolver(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6685 import (
        AbstractAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6686 import (
        AbstractShaftCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6687 import (
        AbstractShaftOrHousingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6688 import (
        AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6689 import (
        AGMAGleasonConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6690 import (
        AGMAGleasonConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6691 import (
        AGMAGleasonConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6692 import (
        AssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6693 import (
        BearingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6694 import (
        BeltConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6695 import (
        BeltDriveCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6696 import (
        BevelDifferentialGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6697 import (
        BevelDifferentialGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6698 import (
        BevelDifferentialGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6699 import (
        BevelDifferentialPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6700 import (
        BevelDifferentialSunGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6701 import (
        BevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6702 import (
        BevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6703 import (
        BevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6704 import (
        BoltCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6705 import (
        BoltedJointCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6706 import (
        ClutchConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6707 import (
        ClutchCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6708 import (
        ClutchHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6709 import (
        CoaxialConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6710 import (
        ComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6711 import (
        ConceptCouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6712 import (
        ConceptCouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6713 import (
        ConceptCouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6714 import (
        ConceptGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6715 import (
        ConceptGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6716 import (
        ConceptGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6717 import (
        ConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6718 import (
        ConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6719 import (
        ConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6720 import (
        ConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6721 import (
        ConnectorCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6722 import (
        CouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6723 import (
        CouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6724 import (
        CouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6725 import (
        CriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6726 import (
        CriticalSpeedAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6727 import (
        CriticalSpeedAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6728 import (
        CVTBeltConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6729 import (
        CVTCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6730 import (
        CVTPulleyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6731 import (
        CycloidalAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6732 import (
        CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6733 import (
        CycloidalDiscCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6734 import (
        CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6735 import (
        CylindricalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6736 import (
        CylindricalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6737 import (
        CylindricalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6738 import (
        CylindricalPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6739 import (
        DatumCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6740 import (
        ExternalCADModelCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6741 import (
        FaceGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6742 import (
        FaceGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6743 import (
        FaceGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6744 import (
        FEPartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6745 import (
        FlexiblePinAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6746 import (
        GearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6747 import (
        GearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6748 import (
        GearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6749 import (
        GuideDxfModelCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6750 import (
        HypoidGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6751 import (
        HypoidGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6752 import (
        HypoidGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6753 import (
        InterMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6754 import (
        KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6755 import (
        KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6756 import (
        KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6757 import (
        KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6758 import (
        KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6759 import (
        KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6760 import (
        KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6761 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6762 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6763 import (
        MassDiscCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6764 import (
        MeasurementComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6765 import (
        MicrophoneArrayCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6766 import (
        MicrophoneCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6767 import (
        MountableComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6768 import (
        OilSealCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6769 import (
        PartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6770 import (
        PartToPartShearCouplingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6771 import (
        PartToPartShearCouplingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6772 import (
        PartToPartShearCouplingHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6773 import (
        PlanetaryConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6774 import (
        PlanetaryGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6775 import (
        PlanetCarrierCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6776 import (
        PointLoadCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6777 import (
        PowerLoadCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6778 import (
        PulleyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6779 import (
        RingPinsCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6780 import (
        RingPinsToDiscConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6781 import (
        RollingRingAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6782 import (
        RollingRingConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6783 import (
        RollingRingCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6784 import (
        RootAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6785 import (
        ShaftCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6786 import (
        ShaftHubConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6787 import (
        ShaftToMountableComponentConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6788 import (
        SpecialisedAssemblyCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6789 import (
        SpiralBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6790 import (
        SpiralBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6791 import (
        SpiralBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6792 import (
        SpringDamperConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6793 import (
        SpringDamperCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6794 import (
        SpringDamperHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6795 import (
        StraightBevelDiffGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6796 import (
        StraightBevelDiffGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6797 import (
        StraightBevelDiffGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6798 import (
        StraightBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6799 import (
        StraightBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6800 import (
        StraightBevelGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6801 import (
        StraightBevelPlanetGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6802 import (
        StraightBevelSunGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6803 import (
        SynchroniserCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6804 import (
        SynchroniserHalfCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6805 import (
        SynchroniserPartCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6806 import (
        SynchroniserSleeveCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6807 import (
        TorqueConverterConnectionCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6808 import (
        TorqueConverterCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6809 import (
        TorqueConverterPumpCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6810 import (
        TorqueConverterTurbineCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6811 import (
        UnbalancedMassCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6812 import (
        VirtualComponentCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6813 import (
        WormGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6814 import (
        WormGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6815 import (
        WormGearSetCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6816 import (
        ZerolBevelGearCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6817 import (
        ZerolBevelGearMeshCriticalSpeedAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.critical_speed_analyses._6818 import (
        ZerolBevelGearSetCriticalSpeedAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.critical_speed_analyses._6685": [
            "AbstractAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6686": [
            "AbstractShaftCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6687": [
            "AbstractShaftOrHousingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6688": [
            "AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6689": [
            "AGMAGleasonConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6690": [
            "AGMAGleasonConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6691": [
            "AGMAGleasonConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6692": [
            "AssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6693": [
            "BearingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6694": [
            "BeltConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6695": [
            "BeltDriveCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6696": [
            "BevelDifferentialGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6697": [
            "BevelDifferentialGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6698": [
            "BevelDifferentialGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6699": [
            "BevelDifferentialPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6700": [
            "BevelDifferentialSunGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6701": [
            "BevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6702": [
            "BevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6703": [
            "BevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6704": [
            "BoltCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6705": [
            "BoltedJointCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6706": [
            "ClutchConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6707": [
            "ClutchCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6708": [
            "ClutchHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6709": [
            "CoaxialConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6710": [
            "ComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6711": [
            "ConceptCouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6712": [
            "ConceptCouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6713": [
            "ConceptCouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6714": [
            "ConceptGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6715": [
            "ConceptGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6716": [
            "ConceptGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6717": [
            "ConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6718": [
            "ConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6719": [
            "ConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6720": [
            "ConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6721": [
            "ConnectorCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6722": [
            "CouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6723": [
            "CouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6724": [
            "CouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6725": [
            "CriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6726": [
            "CriticalSpeedAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6727": [
            "CriticalSpeedAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6728": [
            "CVTBeltConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6729": [
            "CVTCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6730": [
            "CVTPulleyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6731": [
            "CycloidalAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6732": [
            "CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6733": [
            "CycloidalDiscCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6734": [
            "CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6735": [
            "CylindricalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6736": [
            "CylindricalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6737": [
            "CylindricalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6738": [
            "CylindricalPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6739": [
            "DatumCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6740": [
            "ExternalCADModelCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6741": [
            "FaceGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6742": [
            "FaceGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6743": [
            "FaceGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6744": [
            "FEPartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6745": [
            "FlexiblePinAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6746": [
            "GearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6747": [
            "GearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6748": [
            "GearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6749": [
            "GuideDxfModelCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6750": [
            "HypoidGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6751": [
            "HypoidGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6752": [
            "HypoidGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6753": [
            "InterMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6754": [
            "KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6755": [
            "KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6756": [
            "KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6757": [
            "KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6758": [
            "KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6759": [
            "KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6760": [
            "KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6761": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6762": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6763": [
            "MassDiscCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6764": [
            "MeasurementComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6765": [
            "MicrophoneArrayCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6766": [
            "MicrophoneCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6767": [
            "MountableComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6768": [
            "OilSealCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6769": [
            "PartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6770": [
            "PartToPartShearCouplingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6771": [
            "PartToPartShearCouplingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6772": [
            "PartToPartShearCouplingHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6773": [
            "PlanetaryConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6774": [
            "PlanetaryGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6775": [
            "PlanetCarrierCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6776": [
            "PointLoadCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6777": [
            "PowerLoadCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6778": [
            "PulleyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6779": [
            "RingPinsCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6780": [
            "RingPinsToDiscConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6781": [
            "RollingRingAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6782": [
            "RollingRingConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6783": [
            "RollingRingCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6784": [
            "RootAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6785": [
            "ShaftCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6786": [
            "ShaftHubConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6787": [
            "ShaftToMountableComponentConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6788": [
            "SpecialisedAssemblyCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6789": [
            "SpiralBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6790": [
            "SpiralBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6791": [
            "SpiralBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6792": [
            "SpringDamperConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6793": [
            "SpringDamperCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6794": [
            "SpringDamperHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6795": [
            "StraightBevelDiffGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6796": [
            "StraightBevelDiffGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6797": [
            "StraightBevelDiffGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6798": [
            "StraightBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6799": [
            "StraightBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6800": [
            "StraightBevelGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6801": [
            "StraightBevelPlanetGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6802": [
            "StraightBevelSunGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6803": [
            "SynchroniserCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6804": [
            "SynchroniserHalfCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6805": [
            "SynchroniserPartCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6806": [
            "SynchroniserSleeveCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6807": [
            "TorqueConverterConnectionCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6808": [
            "TorqueConverterCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6809": [
            "TorqueConverterPumpCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6810": [
            "TorqueConverterTurbineCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6811": [
            "UnbalancedMassCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6812": [
            "VirtualComponentCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6813": [
            "WormGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6814": [
            "WormGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6815": [
            "WormGearSetCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6816": [
            "ZerolBevelGearCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6817": [
            "ZerolBevelGearMeshCriticalSpeedAnalysis"
        ],
        "_private.system_model.analyses_and_results.critical_speed_analyses._6818": [
            "ZerolBevelGearSetCriticalSpeedAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCriticalSpeedAnalysis",
    "AbstractShaftCriticalSpeedAnalysis",
    "AbstractShaftOrHousingCriticalSpeedAnalysis",
    "AbstractShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearMeshCriticalSpeedAnalysis",
    "AGMAGleasonConicalGearSetCriticalSpeedAnalysis",
    "AssemblyCriticalSpeedAnalysis",
    "BearingCriticalSpeedAnalysis",
    "BeltConnectionCriticalSpeedAnalysis",
    "BeltDriveCriticalSpeedAnalysis",
    "BevelDifferentialGearCriticalSpeedAnalysis",
    "BevelDifferentialGearMeshCriticalSpeedAnalysis",
    "BevelDifferentialGearSetCriticalSpeedAnalysis",
    "BevelDifferentialPlanetGearCriticalSpeedAnalysis",
    "BevelDifferentialSunGearCriticalSpeedAnalysis",
    "BevelGearCriticalSpeedAnalysis",
    "BevelGearMeshCriticalSpeedAnalysis",
    "BevelGearSetCriticalSpeedAnalysis",
    "BoltCriticalSpeedAnalysis",
    "BoltedJointCriticalSpeedAnalysis",
    "ClutchConnectionCriticalSpeedAnalysis",
    "ClutchCriticalSpeedAnalysis",
    "ClutchHalfCriticalSpeedAnalysis",
    "CoaxialConnectionCriticalSpeedAnalysis",
    "ComponentCriticalSpeedAnalysis",
    "ConceptCouplingConnectionCriticalSpeedAnalysis",
    "ConceptCouplingCriticalSpeedAnalysis",
    "ConceptCouplingHalfCriticalSpeedAnalysis",
    "ConceptGearCriticalSpeedAnalysis",
    "ConceptGearMeshCriticalSpeedAnalysis",
    "ConceptGearSetCriticalSpeedAnalysis",
    "ConicalGearCriticalSpeedAnalysis",
    "ConicalGearMeshCriticalSpeedAnalysis",
    "ConicalGearSetCriticalSpeedAnalysis",
    "ConnectionCriticalSpeedAnalysis",
    "ConnectorCriticalSpeedAnalysis",
    "CouplingConnectionCriticalSpeedAnalysis",
    "CouplingCriticalSpeedAnalysis",
    "CouplingHalfCriticalSpeedAnalysis",
    "CriticalSpeedAnalysis",
    "CriticalSpeedAnalysisDrawStyle",
    "CriticalSpeedAnalysisOptions",
    "CVTBeltConnectionCriticalSpeedAnalysis",
    "CVTCriticalSpeedAnalysis",
    "CVTPulleyCriticalSpeedAnalysis",
    "CycloidalAssemblyCriticalSpeedAnalysis",
    "CycloidalDiscCentralBearingConnectionCriticalSpeedAnalysis",
    "CycloidalDiscCriticalSpeedAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionCriticalSpeedAnalysis",
    "CylindricalGearCriticalSpeedAnalysis",
    "CylindricalGearMeshCriticalSpeedAnalysis",
    "CylindricalGearSetCriticalSpeedAnalysis",
    "CylindricalPlanetGearCriticalSpeedAnalysis",
    "DatumCriticalSpeedAnalysis",
    "ExternalCADModelCriticalSpeedAnalysis",
    "FaceGearCriticalSpeedAnalysis",
    "FaceGearMeshCriticalSpeedAnalysis",
    "FaceGearSetCriticalSpeedAnalysis",
    "FEPartCriticalSpeedAnalysis",
    "FlexiblePinAssemblyCriticalSpeedAnalysis",
    "GearCriticalSpeedAnalysis",
    "GearMeshCriticalSpeedAnalysis",
    "GearSetCriticalSpeedAnalysis",
    "GuideDxfModelCriticalSpeedAnalysis",
    "HypoidGearCriticalSpeedAnalysis",
    "HypoidGearMeshCriticalSpeedAnalysis",
    "HypoidGearSetCriticalSpeedAnalysis",
    "InterMountableComponentConnectionCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCriticalSpeedAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCriticalSpeedAnalysis",
    "MassDiscCriticalSpeedAnalysis",
    "MeasurementComponentCriticalSpeedAnalysis",
    "MicrophoneArrayCriticalSpeedAnalysis",
    "MicrophoneCriticalSpeedAnalysis",
    "MountableComponentCriticalSpeedAnalysis",
    "OilSealCriticalSpeedAnalysis",
    "PartCriticalSpeedAnalysis",
    "PartToPartShearCouplingConnectionCriticalSpeedAnalysis",
    "PartToPartShearCouplingCriticalSpeedAnalysis",
    "PartToPartShearCouplingHalfCriticalSpeedAnalysis",
    "PlanetaryConnectionCriticalSpeedAnalysis",
    "PlanetaryGearSetCriticalSpeedAnalysis",
    "PlanetCarrierCriticalSpeedAnalysis",
    "PointLoadCriticalSpeedAnalysis",
    "PowerLoadCriticalSpeedAnalysis",
    "PulleyCriticalSpeedAnalysis",
    "RingPinsCriticalSpeedAnalysis",
    "RingPinsToDiscConnectionCriticalSpeedAnalysis",
    "RollingRingAssemblyCriticalSpeedAnalysis",
    "RollingRingConnectionCriticalSpeedAnalysis",
    "RollingRingCriticalSpeedAnalysis",
    "RootAssemblyCriticalSpeedAnalysis",
    "ShaftCriticalSpeedAnalysis",
    "ShaftHubConnectionCriticalSpeedAnalysis",
    "ShaftToMountableComponentConnectionCriticalSpeedAnalysis",
    "SpecialisedAssemblyCriticalSpeedAnalysis",
    "SpiralBevelGearCriticalSpeedAnalysis",
    "SpiralBevelGearMeshCriticalSpeedAnalysis",
    "SpiralBevelGearSetCriticalSpeedAnalysis",
    "SpringDamperConnectionCriticalSpeedAnalysis",
    "SpringDamperCriticalSpeedAnalysis",
    "SpringDamperHalfCriticalSpeedAnalysis",
    "StraightBevelDiffGearCriticalSpeedAnalysis",
    "StraightBevelDiffGearMeshCriticalSpeedAnalysis",
    "StraightBevelDiffGearSetCriticalSpeedAnalysis",
    "StraightBevelGearCriticalSpeedAnalysis",
    "StraightBevelGearMeshCriticalSpeedAnalysis",
    "StraightBevelGearSetCriticalSpeedAnalysis",
    "StraightBevelPlanetGearCriticalSpeedAnalysis",
    "StraightBevelSunGearCriticalSpeedAnalysis",
    "SynchroniserCriticalSpeedAnalysis",
    "SynchroniserHalfCriticalSpeedAnalysis",
    "SynchroniserPartCriticalSpeedAnalysis",
    "SynchroniserSleeveCriticalSpeedAnalysis",
    "TorqueConverterConnectionCriticalSpeedAnalysis",
    "TorqueConverterCriticalSpeedAnalysis",
    "TorqueConverterPumpCriticalSpeedAnalysis",
    "TorqueConverterTurbineCriticalSpeedAnalysis",
    "UnbalancedMassCriticalSpeedAnalysis",
    "VirtualComponentCriticalSpeedAnalysis",
    "WormGearCriticalSpeedAnalysis",
    "WormGearMeshCriticalSpeedAnalysis",
    "WormGearSetCriticalSpeedAnalysis",
    "ZerolBevelGearCriticalSpeedAnalysis",
    "ZerolBevelGearMeshCriticalSpeedAnalysis",
    "ZerolBevelGearSetCriticalSpeedAnalysis",
)



"""CylindricalGearGrindingWorm"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import constructor, utility
from mastapy._private.gears.manufacturing.cylindrical.cutters import _735
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_GRINDING_WORM = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Cylindrical.Cutters",
    "CylindricalGearGrindingWorm",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.manufacturing.cylindrical.cutters.tangibles import (
        _753,
        _751,
    )
    from mastapy._private.gears.manufacturing.cylindrical.cutters import _736, _729
    from mastapy._private.utility.databases import _1879

    Self = TypeVar("Self", bound="CylindricalGearGrindingWorm")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearGrindingWorm._Cast_CylindricalGearGrindingWorm",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearGrindingWorm",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearGrindingWorm:
    """Special nested class for casting CylindricalGearGrindingWorm to subclasses."""

    __parent__: "CylindricalGearGrindingWorm"

    @property
    def cylindrical_gear_rack_design(
        self: "CastSelf",
    ) -> "_735.CylindricalGearRackDesign":
        return self.__parent__._cast(_735.CylindricalGearRackDesign)

    @property
    def cylindrical_gear_real_cutter_design(
        self: "CastSelf",
    ) -> "_736.CylindricalGearRealCutterDesign":
        from mastapy._private.gears.manufacturing.cylindrical.cutters import _736

        return self.__parent__._cast(_736.CylindricalGearRealCutterDesign)

    @property
    def cylindrical_gear_abstract_cutter_design(
        self: "CastSelf",
    ) -> "_729.CylindricalGearAbstractCutterDesign":
        from mastapy._private.gears.manufacturing.cylindrical.cutters import _729

        return self.__parent__._cast(_729.CylindricalGearAbstractCutterDesign)

    @property
    def named_database_item(self: "CastSelf") -> "_1879.NamedDatabaseItem":
        from mastapy._private.utility.databases import _1879

        return self.__parent__._cast(_1879.NamedDatabaseItem)

    @property
    def cylindrical_gear_grinding_worm(
        self: "CastSelf",
    ) -> "CylindricalGearGrindingWorm":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalGearGrindingWorm(_735.CylindricalGearRackDesign):
    """CylindricalGearGrindingWorm

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_GRINDING_WORM

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def edge_height(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EdgeHeight

        if temp is None:
            return 0.0

        return temp

    @edge_height.setter
    @enforce_parameter_types
    def edge_height(self: "Self", value: "float") -> None:
        self.wrapped.EdgeHeight = float(value) if value is not None else 0.0

    @property
    def flat_tip_width(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FlatTipWidth

        if temp is None:
            return 0.0

        return temp

    @flat_tip_width.setter
    @enforce_parameter_types
    def flat_tip_width(self: "Self", value: "float") -> None:
        self.wrapped.FlatTipWidth = float(value) if value is not None else 0.0

    @property
    def has_tolerances(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.HasTolerances

        if temp is None:
            return False

        return temp

    @has_tolerances.setter
    @enforce_parameter_types
    def has_tolerances(self: "Self", value: "bool") -> None:
        self.wrapped.HasTolerances = bool(value) if value is not None else False

    @property
    def nominal_rack_shape(self: "Self") -> "_753.RackShape":
        """mastapy._private.gears.manufacturing.cylindrical.cutters.tangibles.RackShape

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NominalRackShape

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def nominal_worm_grinder_shape(
        self: "Self",
    ) -> "_751.CylindricalGearWormGrinderShape":
        """mastapy._private.gears.manufacturing.cylindrical.cutters.tangibles.CylindricalGearWormGrinderShape

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NominalWormGrinderShape

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearGrindingWorm":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearGrindingWorm
        """
        return _Cast_CylindricalGearGrindingWorm(self)



"""ISO6336AbstractMetalMeshSingleFlankRating"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable
from mastapy._private.gears.rating.cylindrical.iso6336 import _529
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_ISO6336_ABSTRACT_METAL_MESH_SINGLE_FLANK_RATING = python_net_import(
    "SMT.MastaAPI.Gears.Rating.Cylindrical.ISO6336",
    "ISO6336AbstractMetalMeshSingleFlankRating",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.gears.rating.cylindrical import _487, _492, _493, _470, _478
    from mastapy._private.gears.gear_designs.cylindrical import _1105
    from mastapy._private.gears.rating.cylindrical.iso6336 import _525, _530, _523, _527
    from mastapy._private.gears.rating.cylindrical.din3990 import _544
    from mastapy._private.gears.rating import _377

    Self = TypeVar("Self", bound="ISO6336AbstractMetalMeshSingleFlankRating")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ISO6336AbstractMetalMeshSingleFlankRating._Cast_ISO6336AbstractMetalMeshSingleFlankRating",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ISO6336AbstractMetalMeshSingleFlankRating",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ISO6336AbstractMetalMeshSingleFlankRating:
    """Special nested class for casting ISO6336AbstractMetalMeshSingleFlankRating to subclasses."""

    __parent__: "ISO6336AbstractMetalMeshSingleFlankRating"

    @property
    def iso6336_abstract_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_529.ISO6336AbstractMeshSingleFlankRating":
        return self.__parent__._cast(_529.ISO6336AbstractMeshSingleFlankRating)

    @property
    def cylindrical_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_478.CylindricalMeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical import _478

        return self.__parent__._cast(_478.CylindricalMeshSingleFlankRating)

    @property
    def mesh_single_flank_rating(self: "CastSelf") -> "_377.MeshSingleFlankRating":
        from mastapy._private.gears.rating import _377

        return self.__parent__._cast(_377.MeshSingleFlankRating)

    @property
    def iso63361996_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_523.ISO63361996MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _523

        return self.__parent__._cast(_523.ISO63361996MeshSingleFlankRating)

    @property
    def iso63362006_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_525.ISO63362006MeshSingleFlankRating":
        return self.__parent__._cast(_525.ISO63362006MeshSingleFlankRating)

    @property
    def iso63362019_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_527.ISO63362019MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.iso6336 import _527

        return self.__parent__._cast(_527.ISO63362019MeshSingleFlankRating)

    @property
    def din3990_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "_544.DIN3990MeshSingleFlankRating":
        from mastapy._private.gears.rating.cylindrical.din3990 import _544

        return self.__parent__._cast(_544.DIN3990MeshSingleFlankRating)

    @property
    def iso6336_abstract_metal_mesh_single_flank_rating(
        self: "CastSelf",
    ) -> "ISO6336AbstractMetalMeshSingleFlankRating":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ISO6336AbstractMetalMeshSingleFlankRating(
    _529.ISO6336AbstractMeshSingleFlankRating
):
    """ISO6336AbstractMetalMeshSingleFlankRating

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ISO6336_ABSTRACT_METAL_MESH_SINGLE_FLANK_RATING

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def allowable_stress_number_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AllowableStressNumberContact

        if temp is None:
            return 0.0

        return temp

    @property
    def angle_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AngleFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def approach_factor_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ApproachFactorIntegral

        if temp is None:
            return 0.0

        return temp

    @property
    def approach_factor_of_maximum_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ApproachFactorOfMaximumFlashTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def average_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AverageFlashTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def basic_mean_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BasicMeanFlashTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def basic_rack_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BasicRackFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def bulk_temperature_for_micropitting(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BulkTemperatureForMicropitting

        if temp is None:
            return 0.0

        return temp

    @property
    def bulk_tooth_temperature_flash_temperature_method(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BulkToothTemperatureFlashTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def bulk_tooth_temperature_integral_temperature_method(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.BulkToothTemperatureIntegralTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_exposure_time_flash_temperature_method(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactExposureTimeFlashTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_exposure_time_integral_temperature_method(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactExposureTimeIntegralTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_ratio_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactRatioFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_time_at_high_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactTimeAtHighVelocity

        if temp is None:
            return 0.0

        return temp

    @property
    def contact_time_at_medium_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ContactTimeAtMediumVelocity

        if temp is None:
            return 0.0

        return temp

    @property
    def determinant_tangential_load_in_transverse_plane_for_transverse_load_factor(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.DeterminantTangentialLoadInTransversePlaneForTransverseLoadFactor
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def drive_gear_tip_relief(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DriveGearTipRelief

        if temp is None:
            return 0.0

        return temp

    @property
    def dynamic_factor_source(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DynamicFactorSource

        if temp is None:
            return ""

        return temp

    @property
    def effective_equivalent_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EffectiveEquivalentMisalignment

        if temp is None:
            return 0.0

        return temp

    @property
    def effective_profile_form_deviation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EffectiveProfileFormDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def effective_tip_relief(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EffectiveTipRelief

        if temp is None:
            return 0.0

        return temp

    @property
    def effective_transverse_base_pitch_deviation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EffectiveTransverseBasePitchDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def equivalent_misalignment_due_to_system_deflection(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EquivalentMisalignmentDueToSystemDeflection

        if temp is None:
            return 0.0

        return temp

    @property
    def equivalent_tip_relief_of_pinion(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EquivalentTipReliefOfPinion

        if temp is None:
            return 0.0

        return temp

    @property
    def equivalent_tip_relief_of_wheel(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EquivalentTipReliefOfWheel

        if temp is None:
            return 0.0

        return temp

    @property
    def face_load_factor_bending(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceLoadFactorBending

        if temp is None:
            return 0.0

        return temp

    @property
    def face_load_factor_contact_source(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceLoadFactorContactSource

        if temp is None:
            return ""

        return temp

    @property
    def gear_blank_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GearBlankFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def geometry_factor_at_pinion_tooth_tip(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GeometryFactorAtPinionToothTip

        if temp is None:
            return 0.0

        return temp

    @property
    def helical_load_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HelicalLoadFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def highest_local_contact_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HighestLocalContactTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def initial_equivalent_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InitialEquivalentMisalignment

        if temp is None:
            return 0.0

        return temp

    @property
    def integral_contact_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IntegralContactTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def integral_scuffing_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.IntegralScuffingTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def length_of_path_of_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LengthOfPathOfContact

        if temp is None:
            return 0.0

        return temp

    @property
    def limiting_specific_lubricant_film_thickness_of_the_test_gears(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LimitingSpecificLubricantFilmThicknessOfTheTestGears

        if temp is None:
            return 0.0

        return temp

    @property
    def load_losses_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LoadLossesFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def local_hertzian_contact_stress_calculation_method(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LocalHertzianContactStressCalculationMethod

        if temp is None:
            return ""

        return temp

    @property
    def longest_contact_exposure_time(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LongestContactExposureTime

        if temp is None:
            return 0.0

        return temp

    @property
    def longest_contact_exposure_time_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LongestContactExposureTimeIntegral

        if temp is None:
            return 0.0

        return temp

    @property
    def lubricant_density_at_156_degrees_celsius(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LubricantDensityAt156DegreesCelsius

        if temp is None:
            return 0.0

        return temp

    @property
    def lubricant_density_at_bulk_tooth_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LubricantDensityAtBulkToothTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def lubricant_density_at_micropitting_bulk_tooth_temperature(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LubricantDensityAtMicropittingBulkToothTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def lubricant_dynamic_viscosity_at_tooth_temperature_micropitting(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LubricantDynamicViscosityAtToothTemperatureMicropitting

        if temp is None:
            return 0.0

        return temp

    @property
    def lubricant_factor_flash(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LubricantFactorFlash

        if temp is None:
            return 0.0

        return temp

    @property
    def lubricant_factor_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LubricantFactorIntegral

        if temp is None:
            return 0.0

        return temp

    @property
    def lubrication_system_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LubricationSystemFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def material_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaterialFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def material_parameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaterialParameter

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_base_pitch_deviation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumBasePitchDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_contact_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumContactTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumFlashTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def maximum_profile_form_deviation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MaximumProfileFormDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_coefficient_of_friction_integral_temperature_method(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanCoefficientOfFrictionIntegralTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_coefficient_of_friction_calculated_constant_flash_temperature_method(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.MeanCoefficientOfFrictionCalculatedConstantFlashTemperatureMethod
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanFlashTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def mesh_misalignment_due_to_manufacturing_deviations(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshMisalignmentDueToManufacturingDeviations

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def mesh_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeshStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def micro_geometry_factor_for_the_dynamic_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicroGeometryFactorForTheDynamicLoad

        if temp is None:
            return 0.0

        return temp

    @property
    def micropitting_rating_method(self: "Self") -> "_487.MicropittingRatingMethod":
        """mastapy._private.gears.rating.cylindrical.MicropittingRatingMethod

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingRatingMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Gears.Rating.Cylindrical.MicropittingRatingMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.cylindrical._487", "MicropittingRatingMethod"
        )(value)

    @property
    def micropitting_safety_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MicropittingSafetyFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_lubricant_film_thickness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumLubricantFilmThickness

        if temp is None:
            return 0.0

        return temp

    @property
    def minimum_specific_lubricant_film_thickness_in_the_contact_area(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MinimumSpecificLubricantFilmThicknessInTheContactArea

        if temp is None:
            return 0.0

        return temp

    @property
    def misalignment_due_to_micro_geometry_lead_relief(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MisalignmentDueToMicroGeometryLeadRelief

        if temp is None:
            return 0.0

        return temp

    @property
    def multiple_path_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MultiplePathFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_relative_radius_of_curvature_at_pitch_point_integral_temperature_method(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = (
            self.wrapped.NormalRelativeRadiusOfCurvatureAtPitchPointIntegralTemperatureMethod
        )

        if temp is None:
            return 0.0

        return temp

    @property
    def normal_unit_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NormalUnitLoad

        if temp is None:
            return 0.0

        return temp

    @property
    def optimal_tip_relief(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OptimalTipRelief

        if temp is None:
            return 0.0

        return temp

    @property
    def permissible_specific_lubricant_film_thickness(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PermissibleSpecificLubricantFilmThickness

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @property
    def permissible_specific_lubricant_film_thickness_from_figure_a1(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PermissibleSpecificLubricantFilmThicknessFromFigureA1

        if temp is None:
            return 0.0

        return temp

    @property
    def pressure_viscosity_coefficient_at_38_degrees_c(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PressureViscosityCoefficientAt38DegreesC

        if temp is None:
            return 0.0

        return temp

    @property
    def pressure_viscosity_coefficient_at_bulk_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PressureViscosityCoefficientAtBulkTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def profile_form_deviation_factor_for_the_dynamic_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ProfileFormDeviationFactorForTheDynamicLoad

        if temp is None:
            return 0.0

        return temp

    @property
    def relative_mass_per_unit_face_width(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RelativeMassPerUnitFaceWidth

        if temp is None:
            return 0.0

        return temp

    @property
    def relative_welding_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RelativeWeldingFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def resonance_ratio(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ResonanceRatio

        if temp is None:
            return 0.0

        return temp

    @property
    def resonance_ratio_in_the_main_resonance_range(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ResonanceRatioInTheMainResonanceRange

        if temp is None:
            return 0.0

        return temp

    @property
    def resonance_speed(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ResonanceSpeed

        if temp is None:
            return 0.0

        return temp

    @property
    def roughness_factor_micropitting(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RoughnessFactorMicropitting

        if temp is None:
            return 0.0

        return temp

    @property
    def run_in_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RunInFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def run_in_grade(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RunInGrade

        if temp is None:
            return 0

        return temp

    @property
    def running_in(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RunningIn

        if temp is None:
            return 0.0

        return temp

    @property
    def running_in_profile_form_deviation(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RunningInProfileFormDeviation

        if temp is None:
            return 0.0

        return temp

    @property
    def running_in_allowance_equivalent_misalignment(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RunningInAllowanceEquivalentMisalignment

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_load_safety_factor_integral_temperature_method(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingLoadSafetyFactorIntegralTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_rating_method_flash_temperature_method(
        self: "Self",
    ) -> "_492.ScuffingFlashTemperatureRatingMethod":
        """mastapy._private.gears.rating.cylindrical.ScuffingFlashTemperatureRatingMethod

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingRatingMethodFlashTemperatureMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Cylindrical.ScuffingFlashTemperatureRatingMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.cylindrical._492",
            "ScuffingFlashTemperatureRatingMethod",
        )(value)

    @property
    def scuffing_rating_method_integral_temperature_method(
        self: "Self",
    ) -> "_493.ScuffingIntegralTemperatureRatingMethod":
        """mastapy._private.gears.rating.cylindrical.ScuffingIntegralTemperatureRatingMethod

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingRatingMethodIntegralTemperatureMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.Rating.Cylindrical.ScuffingIntegralTemperatureRatingMethod",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.rating.cylindrical._493",
            "ScuffingIntegralTemperatureRatingMethod",
        )(value)

    @property
    def scuffing_safety_factor_flash_temperature_method(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorFlashTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_safety_factor_integral_temperature_method(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingSafetyFactorIntegralTemperatureMethod

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_temperature_at_high_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingTemperatureAtHighVelocity

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_temperature_at_medium_velocity(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingTemperatureAtMediumVelocity

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_temperature_gradient(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingTemperatureGradient

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_temperature_gradient_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingTemperatureGradientIntegral

        if temp is None:
            return 0.0

        return temp

    @property
    def scuffing_temperature_method(
        self: "Self",
    ) -> "_1105.ScuffingTemperatureMethodsISO":
        """mastapy._private.gears.gear_designs.cylindrical.ScuffingTemperatureMethodsISO

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ScuffingTemperatureMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp,
            "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.ScuffingTemperatureMethodsISO",
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears.gear_designs.cylindrical._1105",
            "ScuffingTemperatureMethodsISO",
        )(value)

    @property
    def single_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SingleStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def stiffness_material_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StiffnessMaterialFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def test_torque(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TestTorque

        if temp is None:
            return 0.0

        return temp

    @property
    def theoretical_single_stiffness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TheoreticalSingleStiffness

        if temp is None:
            return 0.0

        return temp

    @property
    def thermo_elastic_factor_of_maximum_flash_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ThermoElasticFactorOfMaximumFlashTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def tip_relief(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TipRelief

        if temp is None:
            return 0.0

        return temp

    @property
    def tip_relief_calculated(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TipReliefCalculated

        if temp is None:
            return 0.0

        return temp

    @property
    def tip_relief_factor_integral(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TipReliefFactorIntegral

        if temp is None:
            return 0.0

        return temp

    @property
    def tip_relief_factor_for_micropitting(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TipReliefFactorForMicropitting

        if temp is None:
            return 0.0

        return temp

    @property
    def tooth_stiffness_correction_factor(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ToothStiffnessCorrectionFactor

        if temp is None:
            return 0.0

        return temp

    @property
    def transverse_base_pitch_deviation_factor_for_the_dynamic_load(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransverseBasePitchDeviationFactorForTheDynamicLoad

        if temp is None:
            return 0.0

        return temp

    @property
    def transverse_load_factor_contact(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransverseLoadFactorContact

        if temp is None:
            return 0.0

        return temp

    @property
    def transverse_unit_load(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TransverseUnitLoad

        if temp is None:
            return 0.0

        return temp

    @property
    def user_input_scuffing_integral_temperature_for_long_contact_times(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UserInputScuffingIntegralTemperatureForLongContactTimes

        if temp is None:
            return 0.0

        return temp

    @property
    def user_input_scuffing_temperature(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UserInputScuffingTemperature

        if temp is None:
            return 0.0

        return temp

    @property
    def user_input_scuffing_temperature_for_long_contact_times(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.UserInputScuffingTemperatureForLongContactTimes

        if temp is None:
            return 0.0

        return temp

    @property
    def single_flank_rating_of_test_gears_for_micropitting(
        self: "Self",
    ) -> "_525.ISO63362006MeshSingleFlankRating":
        """mastapy._private.gears.rating.cylindrical.iso6336.ISO63362006MeshSingleFlankRating

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SingleFlankRatingOfTestGearsForMicropitting

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def sorted_micro_pitting_results(
        self: "Self",
    ) -> "_470.CylindricalGearMicroPittingResults":
        """mastapy._private.gears.rating.cylindrical.CylindricalGearMicroPittingResults

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SortedMicroPittingResults

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def isodin_cylindrical_gear_single_flank_ratings(
        self: "Self",
    ) -> "List[_530.ISO6336AbstractMetalGearSingleFlankRating]":
        """List[mastapy._private.gears.rating.cylindrical.iso6336.ISO6336AbstractMetalGearSingleFlankRating]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ISODINCylindricalGearSingleFlankRatings

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_ISO6336AbstractMetalMeshSingleFlankRating":
        """Cast to another type.

        Returns:
            _Cast_ISO6336AbstractMetalMeshSingleFlankRating
        """
        return _Cast_ISO6336AbstractMetalMeshSingleFlankRating(self)



"""InterMountableComponentConnectionModalAnalysisAtASpeed"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
    _5271,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_INTER_MOUNTABLE_COMPONENT_CONNECTION_MODAL_ANALYSIS_AT_A_SPEED = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalysesAtASpeed",
    "InterMountableComponentConnectionModalAnalysisAtASpeed",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.connections_and_sockets import _2334
    from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
        _5240,
        _5245,
        _5247,
        _5252,
        _5257,
        _5262,
        _5265,
        _5268,
        _5273,
        _5276,
        _5283,
        _5289,
        _5294,
        _5298,
        _5302,
        _5305,
        _5308,
        _5319,
        _5329,
        _5331,
        _5338,
        _5341,
        _5344,
        _5347,
        _5356,
        _5362,
        _5365,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7706,
        _7703,
    )
    from mastapy._private.system_model.analyses_and_results import _2732, _2736, _2734

    Self = TypeVar(
        "Self", bound="InterMountableComponentConnectionModalAnalysisAtASpeed"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="InterMountableComponentConnectionModalAnalysisAtASpeed._Cast_InterMountableComponentConnectionModalAnalysisAtASpeed",
    )


__docformat__ = "restructuredtext en"
__all__ = ("InterMountableComponentConnectionModalAnalysisAtASpeed",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_InterMountableComponentConnectionModalAnalysisAtASpeed:
    """Special nested class for casting InterMountableComponentConnectionModalAnalysisAtASpeed to subclasses."""

    __parent__: "InterMountableComponentConnectionModalAnalysisAtASpeed"

    @property
    def connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5271.ConnectionModalAnalysisAtASpeed":
        return self.__parent__._cast(_5271.ConnectionModalAnalysisAtASpeed)

    @property
    def connection_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7706.ConnectionStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7706,
        )

        return self.__parent__._cast(_7706.ConnectionStaticLoadAnalysisCase)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7703.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7703,
        )

        return self.__parent__._cast(_7703.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2732.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2732

        return self.__parent__._cast(_2732.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5240.AGMAGleasonConicalGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5240,
        )

        return self.__parent__._cast(
            _5240.AGMAGleasonConicalGearMeshModalAnalysisAtASpeed
        )

    @property
    def belt_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5245.BeltConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5245,
        )

        return self.__parent__._cast(_5245.BeltConnectionModalAnalysisAtASpeed)

    @property
    def bevel_differential_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5247.BevelDifferentialGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5247,
        )

        return self.__parent__._cast(
            _5247.BevelDifferentialGearMeshModalAnalysisAtASpeed
        )

    @property
    def bevel_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5252.BevelGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5252,
        )

        return self.__parent__._cast(_5252.BevelGearMeshModalAnalysisAtASpeed)

    @property
    def clutch_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5257.ClutchConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5257,
        )

        return self.__parent__._cast(_5257.ClutchConnectionModalAnalysisAtASpeed)

    @property
    def concept_coupling_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5262.ConceptCouplingConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5262,
        )

        return self.__parent__._cast(
            _5262.ConceptCouplingConnectionModalAnalysisAtASpeed
        )

    @property
    def concept_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5265.ConceptGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5265,
        )

        return self.__parent__._cast(_5265.ConceptGearMeshModalAnalysisAtASpeed)

    @property
    def conical_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5268.ConicalGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5268,
        )

        return self.__parent__._cast(_5268.ConicalGearMeshModalAnalysisAtASpeed)

    @property
    def coupling_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5273.CouplingConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5273,
        )

        return self.__parent__._cast(_5273.CouplingConnectionModalAnalysisAtASpeed)

    @property
    def cvt_belt_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5276.CVTBeltConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5276,
        )

        return self.__parent__._cast(_5276.CVTBeltConnectionModalAnalysisAtASpeed)

    @property
    def cylindrical_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5283.CylindricalGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5283,
        )

        return self.__parent__._cast(_5283.CylindricalGearMeshModalAnalysisAtASpeed)

    @property
    def face_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5289.FaceGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5289,
        )

        return self.__parent__._cast(_5289.FaceGearMeshModalAnalysisAtASpeed)

    @property
    def gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5294.GearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5294,
        )

        return self.__parent__._cast(_5294.GearMeshModalAnalysisAtASpeed)

    @property
    def hypoid_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5298.HypoidGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5298,
        )

        return self.__parent__._cast(_5298.HypoidGearMeshModalAnalysisAtASpeed)

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5302.KlingelnbergCycloPalloidConicalGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5302,
        )

        return self.__parent__._cast(
            _5302.KlingelnbergCycloPalloidConicalGearMeshModalAnalysisAtASpeed
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5305.KlingelnbergCycloPalloidHypoidGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5305,
        )

        return self.__parent__._cast(
            _5305.KlingelnbergCycloPalloidHypoidGearMeshModalAnalysisAtASpeed
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5308.KlingelnbergCycloPalloidSpiralBevelGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5308,
        )

        return self.__parent__._cast(
            _5308.KlingelnbergCycloPalloidSpiralBevelGearMeshModalAnalysisAtASpeed
        )

    @property
    def part_to_part_shear_coupling_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5319.PartToPartShearCouplingConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5319,
        )

        return self.__parent__._cast(
            _5319.PartToPartShearCouplingConnectionModalAnalysisAtASpeed
        )

    @property
    def ring_pins_to_disc_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5329.RingPinsToDiscConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5329,
        )

        return self.__parent__._cast(
            _5329.RingPinsToDiscConnectionModalAnalysisAtASpeed
        )

    @property
    def rolling_ring_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5331.RollingRingConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5331,
        )

        return self.__parent__._cast(_5331.RollingRingConnectionModalAnalysisAtASpeed)

    @property
    def spiral_bevel_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5338.SpiralBevelGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5338,
        )

        return self.__parent__._cast(_5338.SpiralBevelGearMeshModalAnalysisAtASpeed)

    @property
    def spring_damper_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5341.SpringDamperConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5341,
        )

        return self.__parent__._cast(_5341.SpringDamperConnectionModalAnalysisAtASpeed)

    @property
    def straight_bevel_diff_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5344.StraightBevelDiffGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5344,
        )

        return self.__parent__._cast(
            _5344.StraightBevelDiffGearMeshModalAnalysisAtASpeed
        )

    @property
    def straight_bevel_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5347.StraightBevelGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5347,
        )

        return self.__parent__._cast(_5347.StraightBevelGearMeshModalAnalysisAtASpeed)

    @property
    def torque_converter_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5356.TorqueConverterConnectionModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5356,
        )

        return self.__parent__._cast(
            _5356.TorqueConverterConnectionModalAnalysisAtASpeed
        )

    @property
    def worm_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5362.WormGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5362,
        )

        return self.__parent__._cast(_5362.WormGearMeshModalAnalysisAtASpeed)

    @property
    def zerol_bevel_gear_mesh_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "_5365.ZerolBevelGearMeshModalAnalysisAtASpeed":
        from mastapy._private.system_model.analyses_and_results.modal_analyses_at_a_speed import (
            _5365,
        )

        return self.__parent__._cast(_5365.ZerolBevelGearMeshModalAnalysisAtASpeed)

    @property
    def inter_mountable_component_connection_modal_analysis_at_a_speed(
        self: "CastSelf",
    ) -> "InterMountableComponentConnectionModalAnalysisAtASpeed":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class InterMountableComponentConnectionModalAnalysisAtASpeed(
    _5271.ConnectionModalAnalysisAtASpeed
):
    """InterMountableComponentConnectionModalAnalysisAtASpeed

    This is a mastapy class.
    """

    TYPE: ClassVar[
        "Type"
    ] = _INTER_MOUNTABLE_COMPONENT_CONNECTION_MODAL_ANALYSIS_AT_A_SPEED

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def connection_design(self: "Self") -> "_2334.InterMountableComponentConnection":
        """mastapy._private.system_model.connections_and_sockets.InterMountableComponentConnection

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_InterMountableComponentConnectionModalAnalysisAtASpeed":
        """Cast to another type.

        Returns:
            _Cast_InterMountableComponentConnectionModalAnalysisAtASpeed
        """
        return _Cast_InterMountableComponentConnectionModalAnalysisAtASpeed(self)
